@@ -5,8 +5,8 @@ class ctpysql:
         self.conn = conn
         self.Error = Error
 
-    def truncate (self, table):
-        sql = "truncate {0}".format(table)
+    def truncate (self, table_name):
+        sql = "truncate {0}".format(table_name)
         try:
             cursor = self.conn.cursor()
             cursor.execute(sql)
@@ -18,11 +18,11 @@ class ctpysql:
             return e
 
 
-    def insert (self, table, dic):
+    def insert (self, table_name, dic):
         # dic: insert values with {'dic': 'dictionary'}
         columns = ', '.join("`" + str(i).replace('/', '_') + "`" for i in dic.keys())
         values = ', '.join("'" + str(i).replace('/', '_') + "'" for i in dic.values())
-        sql = "INSERT INTO {0} ({1}) VALUES ({2})".format(table, columns, values)
+        sql = "INSERT INTO {0} ({1}) VALUES ({2})".format(table_name, columns, values)
         try:
             cursor = self.conn.cursor()
             cursor.execute(sql)
@@ -33,7 +33,7 @@ class ctpysql:
         except Error as e:
             return e
 
-    def fetch(self, table, case, type, dic):
+    def fetch(self, table_name, case, type, dic):
         # case: all or one
         # type: dic|dictionary or ... (everything else fetch it simply)
         # dic: condition values with {'dic': 'dictionary'}
@@ -45,7 +45,7 @@ class ctpysql:
             else:
                 condition += "{0} = {1}".format(i, dic[i])
 
-        sql = "SELECT * FROM {0} WHERE {1}".format(table, condition)
+        sql = "SELECT * FROM {0} WHERE {1}".format(table_name, condition)
         try:
             if type == 'dic' or type == 'dictionary':
                 cursor = self.conn.cursor(dictionary=True)
@@ -64,11 +64,11 @@ class ctpysql:
         except Error as e:
             return e
 
-    def update(self, table, condition=None, condition_value=None, **data):
+    def update(self, table_name, condition=None, condition_value=None, **data):
         # condition: your condition for update
         # condition_value: your condition value for condition
         # data: kwargs data tp update, like data='data', username='newUsername'
-        sql = "UPDATE {0} SET ".format(table)
+        sql = "UPDATE {0} SET ".format(table_name)
         i = 0
         for key, value in data.items():
             if type(value) is str:
@@ -94,10 +94,10 @@ class ctpysql:
         except Error as e:
             return e
 
-    def delete(self, table, condition, condition_value):
+    def delete(self, table_name, condition, condition_value):
         # condition: your condition for update
         # condition_value: your condition value for condition
-        sql = "DELETE FROM {0} WHERE {1} = {2} ".format(table, condition, condition_value)
+        sql = "DELETE FROM {0} WHERE {1} = {2} ".format(table_name, condition, condition_value)
         try:
             cursor = self.conn.cursor()
             cursor.execute(sql)
@@ -122,10 +122,10 @@ class ctpysql:
         except Error as e:
             return e
 
-    def order(self, table, **data):
+    def order(self, table_name, **data):
         # table: table name
         # **data: kwargs data like: name="ASC", id="DESC"
-        sql = "SELECT * FROM {0} ORDER BY ".format(table)
+        sql = "SELECT * FROM {0} ORDER BY ".format(table_name)
         i = 0
         for key, value in data.items():
             sql += "{0} {1}".format(key, value)
@@ -142,3 +142,25 @@ class ctpysql:
 
         except Error as e:
             return e
+
+    def create_table(self, table_name, **data):
+        sql = "CREATE TABLE {0} ".format(table_name)
+        sql += """("""
+        i = 0
+        for key, value in data.items():
+            sql += "{0} {1}".format(key, value)
+
+            if i < len(data.items())-1:
+                sql += ", "
+            i += 1
+
+        sql += """)"""
+        try:
+            cursor = self.conn.cursor()
+            cursor.execute(sql)
+            self.conn.commit()
+            cursor.close()
+            return "Success"
+
+        except Error as e:
+            return e
